@@ -1,7 +1,10 @@
-import os
 import jinja2
 import jinja2.ext
-from scss import Scss
+try:
+    from scss import Scss
+except ImportError:
+    from strange_case import require_package
+    require_package('PySCSS')
 
 from strange_case.registry import Registry
 from strange_case.nodes import FileNode
@@ -40,17 +43,17 @@ class ScssNode(FileNode):
     def generate_file(self, site, source_path, target_path):
         scss_content = open(source_path, 'r').read()
         css_content = scss_compiler(scss_content)
-        with open(target_path) as f:
+        with open(target_path, 'w') as f:
             f.write(css_content)
         self.files_written.append(target_path)
 
 
-def scss_processor(config, source_path, target_path):
-    if config['target_name'][-4:] == 'scss':
-        config['target_name'][-4:] = 'css'
+def processor(config, source_path, target_path):
+    if config['target_name'].endswith('.scss'):
+        config['target_name'] = config['target_name'][:-4] + 'css'
 
     scss_node = ScssNode(config, source_path, target_path)
     return (scss_node,)
 
-Registry.register('scss', scss_processor)
+Registry.register('scss', processor)
 Registry.associate('scss', ['*.scss'])
