@@ -1,5 +1,5 @@
 import urllib
-from copy import deepcopy
+from strange_case.config_dict import config_copy
 
 
 def check_config_first(fn):
@@ -109,7 +109,7 @@ class Node(object):
             i += 1
 
     def config_copy(self, all=False, **kwargs):
-        node_config = deepcopy(self.config)
+        node_config = config_copy(self.config, self)
 
         # not merged
         if not all:
@@ -138,7 +138,7 @@ class Node(object):
     def iterable(self):
         # if this file is an index file, it will not be included in the pages iterator.
         # all other pages and assets are iterable.
-        if self.target_name != self.config['index']:
+        if not self.config['is_index']:
             return True
         return False
 
@@ -190,6 +190,25 @@ class Node(object):
 
         return [page for page in self.parent]
 
+    @property
+    @check_config_first
+    def ancestors(self):
+        """
+        Returns the list of ancestors, top-most first.
+        """
+        current = self
+        ret = [self]
+        while current.parent:
+            for page in current.parent.all():
+                if 'is_index' not in page.config:
+                    print page.config
+                if page.config['is_index'] and page != self:
+                    ret.insert(0, page)
+                    break
+            current = current.parent
+
+        return ret
+
     @property
     @check_config_first
     def next(self):
